'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose-free/lib/model/meta-plugin');
const MoneyPlugin = require('naf-framework-mongoose-free/lib/model/type-money-plugin');

// 账单
// 1,充值:type为1, 缺少 from_id,pay_for为Bill; 因为没有来源;
// 2,退款至余额:type为2, pay_for:tempLessonApply/lessonStudent,有from_id, 有pay_id和is_pay
// 3,直接支付:type为-1 pay_for:tempLessonApply/lessonStudent,有from_id,有pay_id和is_pay
// 4,余额支付:type为-2 pay_for:tempLessonApply/lessonStudent,有from_id,有pay_id和is_pay
const bill = {
  school_id: { type: String, required: false, zh: '学校id', ref: 'School', getProp: [ 'name' ] }, //
  payer_role: { type: String, required: false, zh: '用户角色' }, //
  payer_id: { type: String, required: false, zh: '用户角色id', refPath: 'payer_role' }, //
  pay_for: { type: String, required: false, zh: '原因' }, //
  from_id: { type: String, required: false, zh: '原因id', refPath: 'pay_for' }, //
  type: { type: String, required: false, zh: '来源' }, // 1:充值;2退款至余额;-1:直接支付;-2余额支付
  pay_id: { type: String, required: false, zh: '支付id', ref: 'PayOrder' }, //
  is_pay: { type: String, required: false, default: '0', zh: '是否支付' }, //  0:未支付;1:支付成功;-1:支付失败;-3:已退款
  time: { type: String, required: false, zh: '时间' }, //
};
const schema = new Schema(bill, { toJSON: { getters: true, virtuals: true } });
schema.index({ id: 1 });
schema.index({ 'meta.createdAt': 1 });
schema.index({ school_id: 1 });
schema.index({ payer_role: 1 });
schema.index({ payer_id: 1 });
schema.index({ pay_for: 1 });
schema.index({ from_id: 1 });
schema.index({ type: 1 });
schema.index({ pay_id: 1 });
schema.index({ is_pay: 1 });
schema.index({ time: 1 });

schema.plugin(metaPlugin);
schema.plugin(MoneyPlugin({ zh: '金额', required: false }));

module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('Bill', schema, 'bill');
};
